@@ -2,56 +2,53 @@
 
 constantDensitySampling <- function(x, polygon.id='pID', parallel=FALSE, cores=NULL, n.pts.per.ac=1, min.samples=5, sampling.type='regular', iterations=10) {
   
+  if (!requireNamespace("terra")) {
+    stop('please install the `terra` package', call. = FALSE)
+  }
+  
   # sanity check: this must be a projected CRS
-  if(!is.projected(x)) {
+  if (terra::is.lonlat(x)) {
     stop('input polygons must be in a projected coordinate system with units of meters', call. = FALSE)
   }
   
   ## 2016-10-13: return NULL when there are no features
   # must have > 0 features
-  if(length(x) == 0)
+  if (length(x) == 0)
     return(NULL)
   
   # retain proj4 information
-  p4s <- proj4string(x)
+  p4s <- terra::crs(x)
   
-  ## see https://github.com/ncss-tech/sharpshootR/issues/10
-  ## NOT ready for prime time, usually slower than sequential
-  ## https://github.com/ncss-tech/sharpshootR/issues/10
-  ## requires slightly more RAM
-  ## significant overhead
-  ## not worth doing when nrow(x) < number of cores
-  if(parallel) {
-    
+  # ## see https://github.com/ncss-tech/sharpshootR/issues/10
+  # ## NOT ready for prime time, usually slower than sequential
+  # ## https://github.com/ncss-tech/sharpshootR/issues/10
+  # ## requires slightly more RAM
+  # ## significant overhead
+  # ## not worth doing when nrow(x) < number of cores
+  if (parallel) {
+    .Deprecated(msg = "`parallel` argument is deprecated")
+
     # establish possible number of CPU cores if not specified
-    if(is.null(cores)) {
+    if (is.null(cores)) {
       # the smaller: available CPU cores | number of polygons
       cores <- min(c(parallel::detectCores(), nrow(x)))
     }
-    
+
     # init nodes
     ## TODO: optimal setting for useXDR ?
     ## TODO: makeCluster() [platform agnostic] or makePSOCKcluster() [Windoze]
-    cl <- parallel::makeCluster(cores, useXDR=TRUE)
-    
-    ## probably not required?
-    # # setup clusters
-    # parallel::clusterEvalQ(cl, {
-    #   library(sp)
-    #   library(sharpshootR)
-    #   return(NULL)
-    # })
-    
+    cl <- parallel::makeCluster(cores, useXDR = TRUE)
+
     # parallel sampling
     # sample and return a list, one element / valid polygon
-    res <- parallel::parLapply(cl=cl, X=slot(x, 'polygons'), 
-                                 fun=sample.by.poly, 
-                                 n.pts.per.ac=n.pts.per.ac, 
-                                 min.samples=min.samples, 
-                                 sampling.type=sampling.type, 
-                                 iterations=iterations,
-                                 p4s=p4s)
-    
+    res <- parallel::parLapply(cl = cl, X = split(x, 1:length(x)),
+                               fun = sample.by.poly,
+                               n.pts.per.ac = n.pts.per.ac,
+                               min.samples = min.samples,
+                               sampling.type = sampling.type,
+                               iterations = iterations,
+                               p4s = p4s)
+
     # stop nodes
     parallel::stopCluster(cl)
   }
@@ -59,14 +56,21 @@ constantDensitySampling <- function(x, polygon.id='pID', parallel=FALSE, cores=N
     
   # sequential processing
   # sample and return a list, one element / valid polygon
-  res <- lapply(slot(x, 'polygons'), 
-                FUN=sample.by.poly, 
-                n.pts.per.ac=n.pts.per.ac, 
-                min.samples=min.samples, 
-                sampling.type=sampling.type, 
-                iterations=iterations,
-                p4s=p4s)
-  
+  res <- lapply(
+    1:nrow(x),
+    FUN = function(i) {
+      smp <- sample.by.poly(
+        x[i,],
+        n.pts.per.ac = n.pts.per.ac,
+        min.samples = min.samples,
+        sampling.type = sampling.type,
+        iterations = iterations,
+        p4s = p4s
+      )
+      smp$pID <- i
+      smp
+      }
+    )
   
   # check for NULL in this list:
   # this happens when there aren't enough sample points based on min.samples
@@ -75,41 +79,22 @@ constantDensitySampling <- function(x, polygon.id='pID', parallel=FALSE, cores=N
   #   --> spsample() says: "cannot derive coordinates from non-numeric matrix"
   
   null.items <- which(sapply(res, is.null))
-  if(length(null.items) > 0) {
+  if (length(null.items) > 0) {
     message('some polygons were too small for the requested number of samples')
     res <- res[-null.items]
   }
   
   # if there are no polygons large enough to sample, return NULL
-  if(length(res) < 1)
+  if (length(res) < 1) {
     return(NULL)
-  
-  
-  # when rbind-ing the result there is an error related to duplicate rownames
-  # reset with running counter
-  total <- 0
-  for(i in seq_along(res)) {
-    
-    # number of points
-    n <- length(res[[i]])
-    
-    # new row names seq
-    i.seq <- seq(from=(total + 1), to=(total + n))
-    
-    # reset rownames
-    dimnames(res[[i]]@coords)[[1]] <- as.character(i.seq)
-    
-    # increment counter
-    total <- total + n
+  } else if (length(res) > 1) { 
+    res <- do.call('rbind', res)
+  } else {
+    res <- res[[1]]
   }
   
-  # convert into a single SP object
-  if(length(res) > 0)
-    res <- do.call('rbind', res)
-  
-  # upgrade to SPDF with polygon ID
-  pID.df <- sp::over(res, x)[, polygon.id, drop=FALSE]
-  res <- SpatialPointsDataFrame(res, data=pID.df)
+  # add polygon ID by intersection
+  res[[polygon.id]] <- x[[polygon.id]][[1]][apply(terra::relate(res, x, "intersects"), MARGIN = 1, which)]
 
   return(res)
 }
@@ -121,36 +106,42 @@ constantDensitySampling <- function(x, polygon.id='pID', parallel=FALSE, cores=N
 # min.samples: minimum requested samples / polygon
 # iterations: number of sampling "tries"
 # p4s: proj4string assigned to SpatialPoints object
-sample.by.poly <- function(p, n.pts.per.ac=1, min.samples=5, sampling.type='regular', iterations=10, p4s=NULL) {
+sample.by.poly <- function(p,
+                           n.pts.per.ac = 1,
+                           min.samples = 5,
+                           sampling.type = 'regular',
+                           iterations = 10,
+                           p4s = NULL
+) {
+  
+  if (!requireNamespace("terra")) {
+    stop('please install the `terra` package', call. = FALSE)
+  }
+  
   # convert _projected_ units to acres
-  ac.i <- p@area * 2.47e-4
+  ac.i <- terra::expanse(p) * 2.47e-4
   
   # determine number of points based on requested density
   n.samples <- round(ac.i * n.pts.per.ac)
   
   # polygon must be at least large enough to support requested number of samples
-  if(n.samples >= min.samples) {
+  if (n.samples >= min.samples) {
     # trap errors caused by bad geometry
-    s.i <- try(spsample(p, n=n.samples, type=sampling.type, iter=iterations), silent=TRUE)
+    s.i <- try(terra::spatSample(p, size = n.samples, method = sampling.type), silent = TRUE)
     
     # errors: return NULL
     # invalid geometry could be the cause
-    if(class(s.i) == 'try-error') {
+    if (inherits(s.i, 'try-error')) {
       # print error for debugging
       message(paste0('sample.by.poly: ', attr(s.i, 'condition')), call. = FALSE)
       # can't do much else, move on to the next feature
       return(NULL)
     }
 
-    
     # assign original proj4 string
-    if(!is.null(p4s) & !is.null(s.i))
-      proj4string(s.i) <- p4s
+    if (!is.null(p4s) & !is.null(s.i))
+      terra::crs(s.i) <- p4s
     
     return(s.i)
-  }
-  
-  # not enough samples, return NULL
-  else
-    return(NULL)
+  } else return(NULL)
 }
